Scenarios
*********

Scenarios describe **what you need**. They define the tests and the necessary devices for them. Here you can find all
scenarios that are implemented in this BalderHub package.


.. note::
    This BalderHub project doesn't have any scenarios.


Heart-Rate-Monitor Profile Scenarios
====================================

.. autoclass:: balderhub.ant.scenarios.hrm.BaseHrmScenario
    :members:

.. autoclass:: balderhub.ant.scenarios.hrm.ScenarioHrmBatteryMeasuring
    :members:

.. autoclass:: balderhub.ant.scenarios.hrm.ScenarioHrmDeviceProfileFullTransmissionPattern
    :members:

.. autoclass:: balderhub.ant.scenarios.hrm.ScenarioManualRequestForAck
    :members:

.. autoclass:: balderhub.ant.scenarios.hrm.ScenarioHrmManualRequestForBrdcst
    :members:
